$OpenBSD: patch-test_rtpw_test_sh,v 1.3 2019/02/15 22:30:23 sthen Exp $

Index: test/rtpw_test.sh
--- test/rtpw_test.sh.orig
+++ test/rtpw_test.sh
@@ -54,13 +54,13 @@ key=Ky7cUDT2GnI0XKWYbXv9AYmqbcLsqzL9mvdN9t/G
 
 ARGS="-b $key -a -e 128"
 
 # First, we run "killall" to get rid of all existing rtpw processes.
 # This step also enables this script to clean up after itself; if this
 # script is interrupted after the rtpw processes are started but before
 # they are killed, those processes will linger.  Re-running the script
 # will get rid of them.
 
-killall rtpw 2>/dev/null
+pkill rtpw 2>/dev/null
 
 if test -x $RTPW; then
 
@@ -54,13 +54,13 @@ key=Ky7cUDT2GnI0XKWYbXv9AYmqbcLsqzL9mvdN9t/G
 ARGS="-b $key -a -e 128"
 
-# First, we run "killall" to get rid of all existing rtpw processes.
+# First, we run "pkill" to get rid of all existing rtpw processes.
 # This step also enables this script to clean up after itself; if this
 # script is interrupted after the rtpw processes are started but before
